"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.asyncLocalStorageMiddleware = asyncLocalStorageMiddleware;
exports.getCurrentContext = getCurrentContext;
const semver = require("semver");
const options_1 = require("./options");
let asyncLocalStorage;
async function asyncLocalStorageMiddleware(req, res, next) {
    if (semver.lt(process.versions.node, options_1.requiredNodeJsVersionForLogExecutionID)) {
        // Skip for unsupported Node.js version.
        next();
        return;
    }
    if (!asyncLocalStorage) {
        const asyncHooks = await Promise.resolve().then(() => require('node:async_hooks'));
        asyncLocalStorage = new asyncHooks.AsyncLocalStorage();
    }
    asyncLocalStorage.run({
        executionId: req.executionId,
        spanId: req.spanId,
    }, () => {
        next();
    });
}
function getCurrentContext() {
    if (!asyncLocalStorage) {
        return undefined;
    }
    return asyncLocalStorage.getStore();
}
//# sourceMappingURL=async_local_storage.js.map